@@ -56,8 +56,10 @@ sub simple_type_exceptions {
     DateRange
     DayOfTheWeek
     DistanceUnits
+    DuplicateCampaignOption
     EditorialStatus
     ErrorKeyType
+    FileFormat
     FileOutputType
     ForecastMatchType
     Gender
@@ -67,12 +69,14 @@ sub simple_type_exceptions {
     MasterAccountStatus
     NotParticipatingInMarketplaceReason
     OptInReporting
+    OutputFile
     ParticipationStatus
     RangeNameType
     ResponseStatusCodeType
     SignupStatus
     SpendCapTactic
     SpendCapType
+    Status
     TacticType
     TargetableLevel
     TargetingPremiumType
@@ -89,9 +93,9 @@ sub new {
     $args{ use_wsse_security_headers } = 1       unless exists $args{ use_wsse_security_headers };
     $args{ use_location_service }      = 1       unless exists $args{ use_location_service };
     $args{ cache_expire_time }         = '1 day' unless exists $args{ cache_expire_time };
-    $args{ version }                   = 'V5'    unless exists $args{ version };
+    $args{ version }                   = 'V6'    unless exists $args{ version };
 
-    $args{ uri } = 'http://marketing.ews.yahooapis.com/V5' 
+    $args{ uri } = 'http://marketing.ews.yahooapis.com/V6' 
         unless exists $args{ uri };
 
     my $self = bless \%args, $class;
@@ -774,7 +778,7 @@ See also perldoc Yahoo::Marketing::AccountService
 
 Please see the API docs at 
 
-L<http://searchmarketing.yahoo.com/developer/docs/V5/gsg/index.php#services>
+L<http://searchmarketing.yahoo.com/developer/docs/V6/gsg/index.php#services>
 
 for details about what methods are available from each of the Services.
 
@@ -815,7 +819,7 @@ Get/set the version to be used for requests
 
 Get/set the URI to be used for requests.  
 
-Defaults to http://marketing.ews.yahooapis.com/V5
+Defaults to http://marketing.ews.yahooapis.com/V6
 
 =head2 master_account
 
@@ -827,7 +831,7 @@ Get/set the account to be used for requests.  Not all requests require an accoun
 Any service that deals with Campaigns (or Ad Groups, Ads, or Keywords) requires account
 to be set.
 
-L<http://searchmarketing.yahoo.com/developer/docs/V5/gsg/requests.php#header>
+L<http://searchmarketing.yahoo.com/developer/docs/V6/gsg/requests.php#header>
 
 =head2 immortal
 
@@ -841,13 +845,13 @@ Defaults to false.
 
 Get/set the onBehalfOfUsername to be used for requests.  
 
-L<http://searchmarketing.yahoo.com/developer/docs/V5/gsg/auth.php#onbehalfof>
+L<http://searchmarketing.yahoo.com/developer/docs/V6/gsg/auth.php#onbehalfof>
 
 =head2 on_behalf_of_password
 
 Get/set the onBehalfOfPassword to be used for requests.  
 
-L<http://searchmarketing.yahoo.com/developer/docs/V5/gsg/auth.php#onbehalfof>
+L<http://searchmarketing.yahoo.com/developer/docs/V6/gsg/auth.php#onbehalfof>
 
 =head2 use_wsse_security_headers
 
